@@ -22,15 +22,17 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
+#include <string.h>
 
 #include "afc.h"
 #include "idevice.h"
 #include "debug.h"
 
-// This is the maximum size an AFC data packet can be
+/** The maximum size an AFC data packet can be */
 static const int MAXIMUM_PACKET_SIZE = (2 << 15);
 
-/** Locks an AFC client, done for thread safety stuff
+/**
+ * Locks an AFC client, done for thread safety stuff
  * 
  * @param client The AFC client connection to lock
  */
@@ -40,7 +42,8 @@ static void afc_lock(afc_client_t client)
 	g_mutex_lock(client->mutex);
 }
 
-/** Unlocks an AFC client, done for thread safety stuff.
+/**
+ * Unlocks an AFC client, done for thread safety stuff.
  * 
  * @param client The AFC 
  */
@@ -50,16 +53,17 @@ static void afc_unlock(afc_client_t client)
 	g_mutex_unlock(client->mutex);
 }
 
-/** Makes a connection to the AFC service on the phone. 
+/**
+ * Makes a connection to the AFC service on the phone.
  * 
  * @param device The device to connect to.
  * @param port The destination port.
  * @param client Pointer that will be set to a newly allocated afc_client_t
  *     upon successful return.
  * 
- * @return AFC_E_SUCCESS on success, AFC_E_INVALID_ARGUMENT when device or port
- *     is invalid, AFC_E_MUX_ERROR when the connection failed, or AFC_E_NO_MEM
- *     when there's a memory allocation problem.
+ * @return AFC_E_SUCCESS on success, AFC_E_INVALID_ARG when device or port is
+ *  invalid, AFC_E_MUX_ERROR when the connection failed, or AFC_E_NO_MEM if
+ *  there is a memory allocation problem.
  */
 afc_error_t afc_client_new(idevice_t device, uint16_t port, afc_client_t * client)
 {
@@ -68,7 +72,7 @@ afc_error_t afc_client_new(idevice_t device, uint16_t port, afc_client_t * clien
 		g_thread_init(NULL);
 
 	if (!device || port==0)
-		return AFC_E_INVALID_ARGUMENT;
+		return AFC_E_INVALID_ARG;
 
 	/* attempt connection */
 	idevice_connection_t connection = NULL;
@@ -76,7 +80,7 @@ afc_error_t afc_client_new(idevice_t device, uint16_t port, afc_client_t * clien
 		return AFC_E_MUX_ERROR;
 	}
 
-	afc_client_t client_loc = (afc_client_t) malloc(sizeof(struct afc_client_int));
+	afc_client_t client_loc = (afc_client_t) malloc(sizeof(struct afc_client_private));
 	client_loc->connection = connection;
 
 	/* allocate a packet */
@@ -99,14 +103,15 @@ afc_error_t afc_client_new(idevice_t device, uint16_t port, afc_client_t * clien
 	return AFC_E_SUCCESS;
 }
 
-/** Disconnects an AFC client from the phone.
+/**
+ * Disconnects an AFC client from the phone.
  * 
  * @param client The client to disconnect.
  */
 afc_error_t afc_client_free(afc_client_t client)
 {
 	if (!client || !client->connection || !client->afc_packet)
-		return AFC_E_INVALID_ARGUMENT;
+		return AFC_E_INVALID_ARG;
 
 	idevice_disconnect(client->connection);
 	free(client->afc_packet);
@@ -117,14 +122,15 @@ afc_error_t afc_client_free(afc_client_t client)
 	return AFC_E_SUCCESS;
 }
 
-/** Dispatches an AFC packet over a client.
+/**
+ * Dispatches an AFC packet over a client.
  * 
  * @param client The client to send data through.
  * @param data The data to send.
  * @param length The length to send.
  * @param bytes_sent The number of bytes actually sent.
  *
- * @return AFC_E_SUCCESS on success, or an AFC_E_* error value on error.
+ * @return AFC_E_SUCCESS on success or an AFC_E_* error value.
  * 
  * @warning set client->afc_packet->this_length and
  *          client->afc_packet->entire_length to 0 before calling this.  The
@@ -137,7 +143,7 @@ static afc_error_t afc_dispatch_packet(afc_client_t client, const char *data, ui
 	uint32_t sent = 0;
 
 	if (!client || !client->connection || !client->afc_packet)
-		return AFC_E_INVALID_ARGUMENT;
+		return AFC_E_INVALID_ARG;
 
 	*bytes_sent = 0;
 
@@ -152,9 +158,9 @@ static afc_error_t afc_dispatch_packet(afc_client_t client, const char *data, ui
 	if (!client->afc_packet->this_length) {
 		client->afc_packet->this_length = sizeof(AFCPacket);
 	}
-	// We want to send two segments; buffer+sizeof(AFCPacket) to
-	// this_length is the parameters
-	// And everything beyond that is the next packet. (for writing)
+	/* We want to send two segments; buffer+sizeof(AFCPacket) to this_length
+	   is the parameters and everything beyond that is the next packet.
+	   (for writing) */
 	if (client->afc_packet->this_length != client->afc_packet->entire_length) {
 		offset = client->afc_packet->this_length - sizeof(AFCPacket);
 
@@ -221,14 +227,14 @@ static afc_error_t afc_dispatch_packet(afc_client_t client, const char *data, ui
 	return AFC_E_INTERNAL_ERROR;
 }
 
-/** Receives data through an AFC client and sets a variable to the received data.
+/**
+ * Receives data through an AFC client and sets a variable to the received data.
  * 
  * @param client The client to receive data on.
  * @param dump_here The char* to point to the newly-received data.
  * @param bytes_recv How much data was received.
  * 
- * @return AFC_E_SUCCESS when data has been received, or an AFC_E_* error value
- *         when an error occured.
+ * @return AFC_E_SUCCESS on success or an AFC_E_* error value.
  */
 static afc_error_t afc_receive_data(afc_client_t client, char **dump_here, uint32_t *bytes_recv)
 {
@@ -370,6 +376,9 @@ static afc_error_t afc_receive_data(afc_client_t client, char **dump_here, uint3
 	return AFC_E_SUCCESS;
 }
 
+/**
+ * Returns counts of null characters within a string.
+ */
 static uint32_t count_nullspaces(char *string, uint32_t number)
 {
 	uint32_t i = 0, nulls = 0;
@@ -382,15 +391,25 @@ static uint32_t count_nullspaces(char *string, uint32_t number)
 	return nulls;
 }
 
-static char **make_strings_list(char *tokens, uint32_t true_length)
+/**
+ * Splits a string of tokens by null characters and returns each token in a
+ * char array/list.
+ *
+ * @param tokens The characters to split into a list.
+ * @param length The length of the tokens string.
+ *
+ * @return A char ** list with each token found in the string. The caller is
+ *  responsible for freeing the memory.
+ */
+static char **make_strings_list(char *tokens, uint32_t length)
 {
 	uint32_t nulls = 0, i = 0, j = 0;
 	char **list = NULL;
 
-	if (!tokens || !true_length)
+	if (!tokens || !length)
 		return NULL;
 
-	nulls = count_nullspaces(tokens, true_length);
+	nulls = count_nullspaces(tokens, length);
 	list = (char **) malloc(sizeof(char *) * (nulls + 1));
 	for (i = 0; i < nulls; i++) {
 		list[i] = strdup(tokens + j);
@@ -401,13 +420,15 @@ static char **make_strings_list(char *tokens, uint32_t true_length)
 	return list;
 }
 
-/** Gets a directory listing of the directory requested.
+/**
+ * Gets a directory listing of the directory requested.
  * 
  * @param client The client to get a directory listing from.
  * @param dir The directory to list. (must be a fully-qualified path)
+ * @param list A char list of files in that directory, terminated by an empty
+ *         string or NULL if there was an error.
  * 
- * @return A char ** list of files in that directory, terminated by an empty
- *         string for now or NULL if there was an error.
+ * @return AFC_E_SUCCESS on success or an AFC_E_* error value.
  */
 afc_error_t afc_read_directory(afc_client_t client, const char *dir, char ***list)
 {
@@ -416,11 +437,11 @@ afc_error_t afc_read_directory(afc_client_t client, const char *dir, char ***lis
 	afc_error_t ret = AFC_E_UNKNOWN_ERROR;
 
 	if (!client || !dir || !list || (list && *list))
-		return AFC_E_INVALID_ARGUMENT;
+		return AFC_E_INVALID_ARG;
 
 	afc_lock(client);
 
-	// Send the command
+	/* Send the command */
 	client->afc_packet->operation = AFC_OP_READ_DIR;
 	client->afc_packet->entire_length = 0;
 	client->afc_packet->this_length = 0;
@@ -429,13 +450,13 @@ afc_error_t afc_read_directory(afc_client_t client, const char *dir, char ***lis
 		afc_unlock(client);
 		return AFC_E_NOT_ENOUGH_DATA;
 	}
-	// Receive the data
+	/* Receive the data */
 	ret = afc_receive_data(client, &data, &bytes);
 	if (ret != AFC_E_SUCCESS) {
 		afc_unlock(client);
 		return ret;
 	}
-	// Parse the data
+	/* Parse the data */
 	list_loc = make_strings_list(data, bytes);
 	if (data)
 		free(data);
@@ -446,12 +467,16 @@ afc_error_t afc_read_directory(afc_client_t client, const char *dir, char ***lis
 	return ret;
 }
 
-/** Get device info for a client connection to phone. (free space on disk, etc.)
+/**
+ * Get device info for a client connection to phone. The device information
+ * returned is the device model as well as the free space, the total capacity
+ * and blocksize on the accessed disk partition.
  * 
  * @param client The client to get device info for.
+ * @param infos A char ** list of parameters as given by AFC or NULL if there
+ *  was an error.
  * 
- * @return A char ** list of parameters as given by AFC or NULL if there was an
- *         error.
+ * @return AFC_E_SUCCESS on success or an AFC_E_* error value.
  */
 afc_error_t afc_get_device_info(afc_client_t client, char ***infos)
 {
@@ -460,11 +485,11 @@ afc_error_t afc_get_device_info(afc_client_t client, char ***infos)
 	afc_error_t ret = AFC_E_UNKNOWN_ERROR;
 
 	if (!client || !infos)
-		return AFC_E_INVALID_ARGUMENT;
+		return AFC_E_INVALID_ARG;
 
 	afc_lock(client);
 
-	// Send the command
+	/* Send the command */
 	client->afc_packet->operation = AFC_OP_GET_DEVINFO;
 	client->afc_packet->entire_length = client->afc_packet->this_length = 0;
 	ret = afc_dispatch_packet(client, NULL, 0, &bytes);
@@ -472,13 +497,13 @@ afc_error_t afc_get_device_info(afc_client_t client, char ***infos)
 		afc_unlock(client);
 		return AFC_E_NOT_ENOUGH_DATA;
 	}
-	// Receive the data
+	/* Receive the data */
 	ret = afc_receive_data(client, &data, &bytes);
 	if (ret != AFC_E_SUCCESS) {
 		afc_unlock(client);
 		return ret;
 	}
-	// Parse the data
+	/* Parse the data */
 	list = make_strings_list(data, bytes);
 	if (data)
 		free(data);
@@ -490,7 +515,8 @@ afc_error_t afc_get_device_info(afc_client_t client, char ***infos)
 	return ret;
 }
 
-/** Get a specific key of the device info list for a client connection.
+/**
+ * Get a specific key of the device info list for a client connection.
  * Known key values are: Model, FSTotalBytes, FSFreeBytes and FSBlockSize.
  * This is a helper function for afc_get_device_info().
  *
@@ -507,7 +533,7 @@ afc_error_t afc_get_device_info_key(afc_client_t client, const char *key, char *
 
 	*value = NULL;
 	if (key == NULL)
-		return AFC_E_INVALID_ARGUMENT;
+		return AFC_E_INVALID_ARG;
 
 	ret = afc_get_device_info(client, &kvps);
 	if (ret != AFC_E_SUCCESS)
@@ -525,13 +551,13 @@ afc_error_t afc_get_device_info_key(afc_client_t client, const char *key, char *
 	return ret;
 }
 
-/** Deletes a file or directory.
+/**
+ * Deletes a file or directory.
  * 
  * @param client The client to use.
  * @param path The path to delete. (must be a fully-qualified path)
  * 
- * @return AFC_E_SUCCESS if everythong went well, AFC_E_INVALID_ARGUMENT
- *         if arguments are NULL or invalid, AFC_E_NOT_ENOUGH_DATA otherwise.
+ * @return AFC_E_SUCCESS on success or an AFC_E_* error value.
  */
 afc_error_t afc_remove_path(afc_client_t client, const char *path)
 {
@@ -540,11 +566,11 @@ afc_error_t afc_remove_path(afc_client_t client, const char *path)
 	afc_error_t ret = AFC_E_UNKNOWN_ERROR;
 
 	if (!client || !path || !client->afc_packet || !client->connection)
-		return AFC_E_INVALID_ARGUMENT;
+		return AFC_E_INVALID_ARG;
 
 	afc_lock(client);
 
-	// Send command
+	/* Send command */
 	client->afc_packet->this_length = client->afc_packet->entire_length = 0;
 	client->afc_packet->operation = AFC_OP_REMOVE_PATH;
 	ret = afc_dispatch_packet(client, path, strlen(path)+1, &bytes);
@@ -552,7 +578,7 @@ afc_error_t afc_remove_path(afc_client_t client, const char *path)
 		afc_unlock(client);
 		return AFC_E_NOT_ENOUGH_DATA;
 	}
-	// Receive response
+	/* Receive response */
 	ret = afc_receive_data(client, &response, &bytes);
 	if (response)
 		free(response);
@@ -566,14 +592,14 @@ afc_error_t afc_remove_path(afc_client_t client, const char *path)
 	return ret;
 }
 
-/** Renames a file or directory on the phone.
+/**
+ * Renames a file or directory on the phone.
  * 
  * @param client The client to have rename.
  * @param from The name to rename from. (must be a fully-qualified path)
  * @param to The new name. (must also be a fully-qualified path)
  * 
- * @return AFC_E_SUCCESS if everythong went well, AFC_E_INVALID_ARGUMENT
- *         if arguments are NULL or invalid, AFC_E_NOT_ENOUGH_DATA otherwise.
+ * @return AFC_E_SUCCESS on success or an AFC_E_* error value.
  */
 afc_error_t afc_rename_path(afc_client_t client, const char *from, const char *to)
 {
@@ -583,11 +609,11 @@ afc_error_t afc_rename_path(afc_client_t client, const char *from, const char *t
 	afc_error_t ret = AFC_E_UNKNOWN_ERROR;
 
 	if (!client || !from || !to || !client->afc_packet || !client->connection)
-		return AFC_E_INVALID_ARGUMENT;
+		return AFC_E_INVALID_ARG;
 
 	afc_lock(client);
 
-	// Send command
+	/* Send command */
 	memcpy(send, from, strlen(from) + 1);
 	memcpy(send + strlen(from) + 1, to, strlen(to) + 1);
 	client->afc_packet->entire_length = client->afc_packet->this_length = 0;
@@ -598,7 +624,7 @@ afc_error_t afc_rename_path(afc_client_t client, const char *from, const char *t
 		afc_unlock(client);
 		return AFC_E_NOT_ENOUGH_DATA;
 	}
-	// Receive response
+	/* Receive response */
 	ret = afc_receive_data(client, &response, &bytes);
 	if (response)
 		free(response);
@@ -608,14 +634,14 @@ afc_error_t afc_rename_path(afc_client_t client, const char *from, const char *t
 	return ret;
 }
 
-/** Creates a directory on the phone.
+/**
+ * Creates a directory on the phone.
  * 
  * @param client The client to use to make a directory.
  * @param dir The directory's path. (must be a fully-qualified path, I assume
  *        all other mkdir restrictions apply as well)
  *
- * @return AFC_E_SUCCESS if everythong went well, AFC_E_INVALID_ARGUMENT
- *         if arguments are NULL or invalid, AFC_E_NOT_ENOUGH_DATA otherwise.
+ * @return AFC_E_SUCCESS on success or an AFC_E_* error value.
  */
 afc_error_t afc_make_directory(afc_client_t client, const char *dir)
 {
@@ -624,11 +650,11 @@ afc_error_t afc_make_directory(afc_client_t client, const char *dir)
 	afc_error_t ret = AFC_E_UNKNOWN_ERROR;
 
 	if (!client)
-		return AFC_E_INVALID_ARGUMENT;
+		return AFC_E_INVALID_ARG;
 
 	afc_lock(client);
 
-	// Send command
+	/* Send command */
 	client->afc_packet->operation = AFC_OP_MAKE_DIR;
 	client->afc_packet->this_length = client->afc_packet->entire_length = 0;
 	ret = afc_dispatch_packet(client, dir, strlen(dir)+1, &bytes);
@@ -636,7 +662,7 @@ afc_error_t afc_make_directory(afc_client_t client, const char *dir)
 		afc_unlock(client);
 		return AFC_E_NOT_ENOUGH_DATA;
 	}
-	// Receive response
+	/* Receive response */
 	ret = afc_receive_data(client, &response, &bytes);
 	if (response)
 		free(response);
@@ -646,7 +672,8 @@ afc_error_t afc_make_directory(afc_client_t client, const char *dir)
 	return ret;
 }
 
-/** Gets information about a specific file.
+/**
+ * Gets information about a specific file.
  * 
  * @param client The client to use to get the information of the file.
  * @param path The fully-qualified path to the file. 
@@ -654,8 +681,7 @@ afc_error_t afc_make_directory(afc_client_t client, const char *dir)
  *                 list of strings with the file information.
  *                 Set to NULL before calling this function.
  * 
- * @return AFC_E_SUCCESS on success or an AFC_E_* error value
- *         when something went wrong.
+ * @return AFC_E_SUCCESS on success or an AFC_E_* error value.
  */
 afc_error_t afc_get_file_info(afc_client_t client, const char *path, char ***infolist)
 {
@@ -664,11 +690,11 @@ afc_error_t afc_get_file_info(afc_client_t client, const char *path, char ***inf
 	afc_error_t ret = AFC_E_UNKNOWN_ERROR;
 
 	if (!client || !path || !infolist)
-		return AFC_E_INVALID_ARGUMENT;
+		return AFC_E_INVALID_ARG;
 
 	afc_lock(client);
 
-	// Send command
+	/* Send command */
 	client->afc_packet->operation = AFC_OP_GET_FILE_INFO;
 	client->afc_packet->entire_length = client->afc_packet->this_length = 0;
 	ret = afc_dispatch_packet(client, path, strlen(path)+1, &bytes);
@@ -677,7 +703,7 @@ afc_error_t afc_get_file_info(afc_client_t client, const char *path, char ***inf
 		return AFC_E_NOT_ENOUGH_DATA;
 	}
 
-	// Receive data
+	/* Receive data */
 	ret = afc_receive_data(client, &received, &bytes);
 	if (received) {
 		*infolist = make_strings_list(received, bytes);
@@ -689,7 +715,8 @@ afc_error_t afc_get_file_info(afc_client_t client, const char *path, char ***inf
 	return ret;
 }
 
-/** Opens a file on the phone.
+/**
+ * Opens a file on the phone.
  * 
  * @param client The client to use to open the file. 
  * @param filename The file to open. (must be a fully-qualified path)
@@ -699,7 +726,7 @@ afc_error_t afc_get_file_info(afc_client_t client, const char *path, char ***inf
  * 		    destroying anything previously there.
  * @param handle Pointer to a uint64_t that will hold the handle of the file
  * 
- * @return AFC_E_SUCCESS on success or an AFC_E_* error on failure.
+ * @return AFC_E_SUCCESS on success or an AFC_E_* error value.
  */
 idevice_error_t
 afc_file_open(afc_client_t client, const char *filename,
@@ -710,15 +737,15 @@ afc_file_open(afc_client_t client, const char *filename,
 	char *data = (char *) malloc(sizeof(char) * (8 + strlen(filename) + 1));
 	afc_error_t ret = AFC_E_UNKNOWN_ERROR;
 
-	// set handle to 0 so in case an error occurs, the handle is invalid
+	/* set handle to 0 so in case an error occurs, the handle is invalid */
 	*handle = 0;
 
 	if (!client || !client->connection || !client->afc_packet)
-		return AFC_E_INVALID_ARGUMENT;
+		return AFC_E_INVALID_ARG;
 
 	afc_lock(client);
 
-	// Send command
+	/* Send command */
 	memcpy(data, &file_mode_loc, 8);
 	memcpy(data + 8, filename, strlen(filename));
 	data[8 + strlen(filename)] = '\0';
@@ -732,12 +759,12 @@ afc_file_open(afc_client_t client, const char *filename,
 		afc_unlock(client);
 		return AFC_E_NOT_ENOUGH_DATA;
 	}
-	// Receive the data
+	/* Receive the data */
 	ret = afc_receive_data(client, &data, &bytes);
 	if ((ret == AFC_E_SUCCESS) && (bytes > 0) && data) {
 		afc_unlock(client);
 
-		// Get the file handle
+		/* Get the file handle */
 		memcpy(handle, data, sizeof(uint64_t));
 		free(data);
 		return ret;
@@ -750,7 +777,8 @@ afc_file_open(afc_client_t client, const char *filename,
 	return ret;
 }
 
-/** Attempts to the read the given number of bytes from the given file.
+/**
+ * Attempts to the read the given number of bytes from the given file.
  * 
  * @param client The relevant AFC client
  * @param handle File handle of a previously opened file
@@ -758,7 +786,7 @@ afc_file_open(afc_client_t client, const char *filename,
  * @param length The number of bytes to read
  * @param bytes_read The number of bytes actually read.
  *
- * @return AFC_E_SUCCESS on success or an AFC_E_* error value on error.
+ * @return AFC_E_SUCCESS on success or an AFC_E_* error value.
  */
 idevice_error_t
 afc_file_read(afc_client_t client, uint64_t handle, char *data, uint32_t length, uint32_t *bytes_read)
@@ -769,17 +797,17 @@ afc_file_read(afc_client_t client, uint64_t handle, char *data, uint32_t length,
 	afc_error_t ret = AFC_E_SUCCESS;
 
 	if (!client || !client->afc_packet || !client->connection || handle == 0)
-		return AFC_E_INVALID_ARGUMENT;
+		return AFC_E_INVALID_ARG;
 	debug_info("called for length %i", length);
 
 	afc_lock(client);
 
-	// Looping here to get around the maximum amount of data that
-	// afc_receive_data can handle
+	/* Looping here to get around the maximum amount of data that
+	   afc_receive_data can handle */
 	while (current_count < length) {
 		debug_info("current count is %i but length is %i", current_count, length);
 
-		// Send the read command
+		/* Send the read command */
 		AFCFilePacket *packet = (AFCFilePacket *) malloc(sizeof(AFCFilePacket));
 		packet->filehandle = handle;
 		packet->size = GUINT64_TO_LE(((length - current_count) < MAXIMUM_READ_SIZE) ? (length - current_count) : MAXIMUM_READ_SIZE);
@@ -792,7 +820,7 @@ afc_file_read(afc_client_t client, uint64_t handle, char *data, uint32_t length,
 			afc_unlock(client);
 			return AFC_E_NOT_ENOUGH_DATA;
 		}
-		// Receive the data
+		/* Receive the data */
 		ret = afc_receive_data(client, &input, &bytes_loc);
 		debug_info("afc_receive_data returned error: %d", ret);
 		debug_info("bytes returned: %i", bytes_loc);
@@ -823,7 +851,8 @@ afc_file_read(afc_client_t client, uint64_t handle, char *data, uint32_t length,
 	return ret;
 }
 
-/** Writes a given number of bytes to a file.
+/**
+ * Writes a given number of bytes to a file.
  * 
  * @param client The client to use to write to the file.
  * @param handle File handle of previously opened file. 
@@ -831,7 +860,7 @@ afc_file_read(afc_client_t client, uint64_t handle, char *data, uint32_t length,
  * @param length How much data to write.
  * @param bytes_written The number of bytes actually written to the file.
  * 
- * @return AFC_E_SUCCESS on success, or an AFC_E_* error value on error.
+ * @return AFC_E_SUCCESS on success or an AFC_E_* error value.
  */
 idevice_error_t
 afc_file_write(afc_client_t client, uint64_t handle, const char *data, uint32_t length, uint32_t *bytes_written)
@@ -845,15 +874,15 @@ afc_file_write(afc_client_t client, uint64_t handle, const char *data, uint32_t
 	afc_error_t ret = AFC_E_SUCCESS;
 
 	if (!client || !client->afc_packet || !client->connection || !bytes_written || (handle == 0))
-		return AFC_E_INVALID_ARGUMENT;
+		return AFC_E_INVALID_ARG;
 
 	afc_lock(client);
 
 	debug_info("Write length: %i", length);
 
-	// Divide the file into segments.
+	/* Divide the file into segments. */
 	for (i = 0; i < segments; i++) {
-		// Send the segment
+		/* Send the segment */
 		client->afc_packet->this_length = sizeof(AFCPacket) + 8;
 		client->afc_packet->entire_length = client->afc_packet->this_length + MAXIMUM_WRITE_SIZE;
 		client->afc_packet->operation = AFC_OP_WRITE;
@@ -878,10 +907,9 @@ afc_file_write(afc_client_t client, uint64_t handle, const char *data, uint32_t
 		}
 	}
 
-	// By this point, we should be at the end. i.e. the last segment that
-	// didn't get sent in the for loop
-	// this length is fine because it's always sizeof(AFCPacket) + 8, but
-	// to be sure we do it again
+	/* By this point, we should be at the end. i.e. the last segment that didn't
+	   get sent in the for loop. This length is fine because it's always
+	   sizeof(AFCPacket) + 8, but to be sure we do it again */
 	if (current_count == length) {
 		afc_unlock(client);
 		*bytes_written = current_count;
@@ -917,7 +945,8 @@ afc_file_write(afc_client_t client, uint64_t handle, const char *data, uint32_t
 	return ret;
 }
 
-/** Closes a file on the phone. 
+/**
+ * Closes a file on the phone.
  * 
  * @param client The client to close the file with.
  * @param handle File handle of a previously opened file.
@@ -929,13 +958,13 @@ afc_error_t afc_file_close(afc_client_t client, uint64_t handle)
 	afc_error_t ret = AFC_E_UNKNOWN_ERROR;
 
 	if (!client || (handle == 0))
-		return AFC_E_INVALID_ARGUMENT;
+		return AFC_E_INVALID_ARG;
 
 	afc_lock(client);
 
 	debug_info("File handle %i", handle);
 
-	// Send command
+	/* Send command */
 	memcpy(buffer, &handle, sizeof(uint64_t));
 	client->afc_packet->operation = AFC_OP_FILE_CLOSE;
 	client->afc_packet->entire_length = client->afc_packet->this_length = 0;
@@ -948,7 +977,7 @@ afc_error_t afc_file_close(afc_client_t client, uint64_t handle)
 		return AFC_E_UNKNOWN_ERROR;
 	}
 
-	// Receive the response
+	/* Receive the response */
 	ret = afc_receive_data(client, &buffer, &bytes);
 	if (buffer)
 		free(buffer);
@@ -958,7 +987,8 @@ afc_error_t afc_file_close(afc_client_t client, uint64_t handle)
 	return ret;
 }
 
-/** Locks or unlocks a file on the phone. 
+/**
+ * Locks or unlocks a file on the phone. 
  *
  * makes use of flock on the device, see
  * http://developer.apple.com/documentation/Darwin/Reference/ManPages/man2/flock.2.html
@@ -977,13 +1007,13 @@ afc_error_t afc_file_lock(afc_client_t client, uint64_t handle, afc_lock_op_t op
 	afc_error_t ret = AFC_E_UNKNOWN_ERROR;
 
 	if (!client || (handle == 0))
-		return AFC_E_INVALID_ARGUMENT;
+		return AFC_E_INVALID_ARG;
 
 	afc_lock(client);
 
 	debug_info("file handle %i", handle);
 
-	// Send command
+	/* Send command */
 	memcpy(buffer, &handle, sizeof(uint64_t));
 	memcpy(buffer + 8, &op, 8);
 
@@ -998,7 +1028,7 @@ afc_error_t afc_file_lock(afc_client_t client, uint64_t handle, afc_lock_op_t op
 		debug_info("could not send lock command");
 		return AFC_E_UNKNOWN_ERROR;
 	}
-	// Receive the response
+	/* Receive the response */
 	ret = afc_receive_data(client, &buffer, &bytes);
 	if (buffer) {
 		debug_buffer(buffer, bytes);
@@ -1009,14 +1039,15 @@ afc_error_t afc_file_lock(afc_client_t client, uint64_t handle, afc_lock_op_t op
 	return ret;
 }
 
-/** Seeks to a given position of a pre-opened file on the phone. 
+/**
+ * Seeks to a given position of a pre-opened file on the phone. 
  * 
  * @param client The client to use to seek to the position.
  * @param handle File handle of a previously opened.
  * @param offset Seek offset.
  * @param whence Seeking direction, one of SEEK_SET, SEEK_CUR, or SEEK_END.
  * 
- * @return AFC_E_SUCCESS on success, AFC_E_NOT_ENOUGH_DATA on failure.
+ * @return AFC_E_SUCCESS on success or an AFC_E_* error value.
  */
 afc_error_t afc_file_seek(afc_client_t client, uint64_t handle, int64_t offset, int whence)
 {
@@ -1027,14 +1058,14 @@ afc_error_t afc_file_seek(afc_client_t client, uint64_t handle, int64_t offset,
 	afc_error_t ret = AFC_E_UNKNOWN_ERROR;
 
 	if (!client || (handle == 0))
-		return AFC_E_INVALID_ARGUMENT;
+		return AFC_E_INVALID_ARG;
 
 	afc_lock(client);
 
-	// Send the command
-	memcpy(buffer, &handle, sizeof(uint64_t));	// handle
-	memcpy(buffer + 8, &whence_loc, sizeof(uint64_t));	// fromwhere
-	memcpy(buffer + 16, &offset_loc, sizeof(uint64_t));	// offset
+	/* Send the command */
+	memcpy(buffer, &handle, sizeof(uint64_t));	/* handle */
+	memcpy(buffer + 8, &whence_loc, sizeof(uint64_t));	/* fromwhere */
+	memcpy(buffer + 16, &offset_loc, sizeof(uint64_t));	/* offset */
 	client->afc_packet->operation = AFC_OP_FILE_SEEK;
 	client->afc_packet->this_length = client->afc_packet->entire_length = 0;
 	ret = afc_dispatch_packet(client, buffer, 24, &bytes);
@@ -1045,7 +1076,7 @@ afc_error_t afc_file_seek(afc_client_t client, uint64_t handle, int64_t offset,
 		afc_unlock(client);
 		return AFC_E_NOT_ENOUGH_DATA;
 	}
-	// Receive response
+	/* Receive response */
 	ret = afc_receive_data(client, &buffer, &bytes);
 	if (buffer)
 		free(buffer);
@@ -1055,13 +1086,14 @@ afc_error_t afc_file_seek(afc_client_t client, uint64_t handle, int64_t offset,
 	return ret;
 }
 
-/** Returns current position in a pre-opened file on the phone.
+/**
+ * Returns current position in a pre-opened file on the phone.
  * 
  * @param client The client to use.
  * @param handle File handle of a previously opened file.
  * @param position Position in bytes of indicator
  * 
- * @return AFC_E_SUCCESS on success, AFC_E_NOT_ENOUGH_DATA on failure.
+ * @return AFC_E_SUCCESS on success or an AFC_E_* error value.
  */
 afc_error_t afc_file_tell(afc_client_t client, uint64_t handle, uint64_t *position)
 {
@@ -1070,12 +1102,12 @@ afc_error_t afc_file_tell(afc_client_t client, uint64_t handle, uint64_t *positi
 	afc_error_t ret = AFC_E_UNKNOWN_ERROR;
 
 	if (!client || (handle == 0))
-		return AFC_E_INVALID_ARGUMENT;
+		return AFC_E_INVALID_ARG;
 
 	afc_lock(client);
 
-	// Send the command
-	memcpy(buffer, &handle, sizeof(uint64_t));	// handle
+	/* Send the command */
+	memcpy(buffer, &handle, sizeof(uint64_t));	/* handle */
 	client->afc_packet->operation = AFC_OP_FILE_TELL;
 	client->afc_packet->this_length = client->afc_packet->entire_length = 0;
 	ret = afc_dispatch_packet(client, buffer, 8, &bytes);
@@ -1087,7 +1119,7 @@ afc_error_t afc_file_tell(afc_client_t client, uint64_t handle, uint64_t *positi
 		return AFC_E_NOT_ENOUGH_DATA;
 	}
 
-	// Receive the data
+	/* Receive the data */
 	ret = afc_receive_data(client, &buffer, &bytes);
 	if (bytes > 0 && buffer) {
 		/* Get the position */
@@ -1102,13 +1134,14 @@ afc_error_t afc_file_tell(afc_client_t client, uint64_t handle, uint64_t *positi
 	return ret;
 }
 
-/** Sets the size of a file on the phone.
+/**
+ * Sets the size of a file on the phone.
  * 
  * @param client The client to use to set the file size.
  * @param handle File handle of a previously opened file.
  * @param newsize The size to set the file to. 
  * 
- * @return 0 on success, -1 on failure. 
+ * @return AFC_E_SUCCESS on success or an AFC_E_* error value.
  * 
  * @note This function is more akin to ftruncate than truncate, and truncate
  *       calls would have to open the file before calling this, sadly.
@@ -1121,13 +1154,13 @@ afc_error_t afc_file_truncate(afc_client_t client, uint64_t handle, uint64_t new
 	afc_error_t ret = AFC_E_UNKNOWN_ERROR;
 
 	if (!client || (handle == 0))
-		return AFC_E_INVALID_ARGUMENT;
+		return AFC_E_INVALID_ARG;
 
 	afc_lock(client);
 
-	// Send command
-	memcpy(buffer, &handle, sizeof(uint64_t));	// handle
-	memcpy(buffer + 8, &newsize_loc, sizeof(uint64_t));	// newsize
+	/* Send command */
+	memcpy(buffer, &handle, sizeof(uint64_t));	/* handle */
+	memcpy(buffer + 8, &newsize_loc, sizeof(uint64_t));	/* newsize */
 	client->afc_packet->operation = AFC_OP_FILE_SET_SIZE;
 	client->afc_packet->this_length = client->afc_packet->entire_length = 0;
 	ret = afc_dispatch_packet(client, buffer, 16, &bytes);
@@ -1138,7 +1171,7 @@ afc_error_t afc_file_truncate(afc_client_t client, uint64_t handle, uint64_t new
 		afc_unlock(client);
 		return AFC_E_NOT_ENOUGH_DATA;
 	}
-	// Receive response
+	/* Receive response */
 	ret = afc_receive_data(client, &buffer, &bytes);
 	if (buffer)
 		free(buffer);
@@ -1148,14 +1181,14 @@ afc_error_t afc_file_truncate(afc_client_t client, uint64_t handle, uint64_t new
 	return ret;
 }
 
-/** Sets the size of a file on the phone without prior opening it.
+/**
+ * Sets the size of a file on the phone without prior opening it.
  * 
  * @param client The client to use to set the file size.
  * @param path The path of the file to be truncated.
  * @param newsize The size to set the file to. 
  * 
- * @return AFC_E_SUCCESS if everything went well, AFC_E_INVALID_ARGUMENT
- *         if arguments are NULL or invalid, AFC_E_NOT_ENOUGH_DATA otherwise.
+ * @return AFC_E_SUCCESS on success or an AFC_E_* error value.
  */
 afc_error_t afc_truncate(afc_client_t client, const char *path, uint64_t newsize)
 {
@@ -1166,11 +1199,11 @@ afc_error_t afc_truncate(afc_client_t client, const char *path, uint64_t newsize
 	afc_error_t ret = AFC_E_UNKNOWN_ERROR;
 
 	if (!client || !path || !client->afc_packet || !client->connection)
-		return AFC_E_INVALID_ARGUMENT;
+		return AFC_E_INVALID_ARG;
 
 	afc_lock(client);
 
-	// Send command
+	/* Send command */
 	memcpy(send, &size_requested, 8);
 	memcpy(send + 8, path, strlen(path) + 1);
 	client->afc_packet->entire_length = client->afc_packet->this_length = 0;
@@ -1181,7 +1214,7 @@ afc_error_t afc_truncate(afc_client_t client, const char *path, uint64_t newsize
 		afc_unlock(client);
 		return AFC_E_NOT_ENOUGH_DATA;
 	}
-	// Receive response
+	/* Receive response */
 	ret = afc_receive_data(client, &response, &bytes);
 	if (response)
 		free(response);
@@ -1191,15 +1224,15 @@ afc_error_t afc_truncate(afc_client_t client, const char *path, uint64_t newsize
 	return ret;
 }
 
-/** Creates a hard link or symbolic link on the device. 
+/**
+ * Creates a hard link or symbolic link on the device. 
  * 
  * @param client The client to use for making a link
- * @param type 1 = hard link, 2 = symlink
+ * @param linktype 1 = hard link, 2 = symlink
  * @param target The file to be linked.
  * @param linkname The name of link.
  * 
- * @return AFC_E_SUCCESS if everything went well, AFC_E_INVALID_ARGUMENT
- *         if arguments are NULL or invalid, AFC_E_NOT_ENOUGH_DATA otherwise.
+ * @return AFC_E_SUCCESS on success or an AFC_E_* error value.
  */
 afc_error_t afc_make_link(afc_client_t client, afc_link_type_t linktype, const char *target, const char *linkname)
 {
@@ -1210,7 +1243,7 @@ afc_error_t afc_make_link(afc_client_t client, afc_link_type_t linktype, const c
 	afc_error_t ret = AFC_E_UNKNOWN_ERROR;
 
 	if (!client || !target || !linkname || !client->afc_packet || !client->connection)
-		return AFC_E_INVALID_ARGUMENT;
+		return AFC_E_INVALID_ARG;
 
 	afc_lock(client);
 
@@ -1218,7 +1251,7 @@ afc_error_t afc_make_link(afc_client_t client, afc_link_type_t linktype, const c
 	debug_info("target: %s, length:%d", target, strlen(target));
 	debug_info("linkname: %s, length:%d", linkname, strlen(linkname));
 
-	// Send command
+	/* Send command */
 	memcpy(send, &type, 8);
 	memcpy(send + 8, target, strlen(target) + 1);
 	memcpy(send + 8 + strlen(target) + 1, linkname, strlen(linkname) + 1);
@@ -1230,7 +1263,7 @@ afc_error_t afc_make_link(afc_client_t client, afc_link_type_t linktype, const c
 		afc_unlock(client);
 		return AFC_E_NOT_ENOUGH_DATA;
 	}
-	// Receive response
+	/* Receive response */
 	ret = afc_receive_data(client, &response, &bytes);
 	if (response)
 		free(response);
@@ -1240,14 +1273,14 @@ afc_error_t afc_make_link(afc_client_t client, afc_link_type_t linktype, const c
 	return ret;
 }
 
-/** Sets the modification time of a file on the phone.
+/**
+ * Sets the modification time of a file on the phone.
  * 
  * @param client The client to use to set the file size.
  * @param path Path of the file for which the modification time should be set.
  * @param mtime The modification time to set in nanoseconds since epoch.
  * 
- * @return AFC_E_SUCCESS if everything went well, AFC_E_INVALID_ARGUMENT
- *         if arguments are NULL or invalid, AFC_E_NOT_ENOUGH_DATA otherwise.
+ * @return AFC_E_SUCCESS on success or an AFC_E_* error value.
  */
 afc_error_t afc_set_file_time(afc_client_t client, const char *path, uint64_t mtime)
 {
@@ -1258,11 +1291,11 @@ afc_error_t afc_set_file_time(afc_client_t client, const char *path, uint64_t mt
 	afc_error_t ret = AFC_E_UNKNOWN_ERROR;
 
 	if (!client || !path || !client->afc_packet || !client->connection)
-		return AFC_E_INVALID_ARGUMENT;
+		return AFC_E_INVALID_ARG;
 
 	afc_lock(client);
 
-	// Send command
+	/* Send command */
 	memcpy(send, &mtime_loc, 8);
 	memcpy(send + 8, path, strlen(path) + 1);
 	client->afc_packet->entire_length = client->afc_packet->this_length = 0;
@@ -1273,7 +1306,7 @@ afc_error_t afc_set_file_time(afc_client_t client, const char *path, uint64_t mt
 		afc_unlock(client);
 		return AFC_E_NOT_ENOUGH_DATA;
 	}
-	// Receive response
+	/* Receive response */
 	ret = afc_receive_data(client, &response, &bytes);
 	if (response)
 		free(response);
